@@ -3,12 +3,13 @@ package WWW::ProxyChecker;
 use warnings;
 use strict;
 
-our $VERSION = '0.002';
+our $VERSION = '1.001001'; # VERSION
+
 use Carp;
 use LWP::UserAgent;
 use IO::Pipe;
-use base 'Class::Data::Accessor';
-__PACKAGE__->mk_classaccessors qw(
+use base 'Class::Accessor::Grouped';
+__PACKAGE__->mk_group_accessors(simple => qw/
     max_kids
     debug
     alive
@@ -16,7 +17,7 @@ __PACKAGE__->mk_classaccessors qw(
     max_working_per_kid
     timeout
     agent
-);
+/);
 
 sub new {
     my $self = bless {}, shift;
@@ -267,7 +268,7 @@ of simultaneous connections that you will have open. B<Defaults to:> C<20>
     ->new( max_working_per_child => 2 );
 
 B<Optional>. Takes a positive integer as a value. Specifies how many
-working proxies each sub proccess should find before aborting (it will
+working proxies each sub process should find before aborting (it will
 also abort if proxy list is exhausted). In other words, setting C<20>
 C<max_kids> and C<max_working_per_child> to C<2> will give you 40 working
 proxies at most, no matter how many are in the original list. Specifying
@@ -327,50 +328,41 @@ will set a new value. All of these return a currently set value:
 
 See C<CONSTRUCTOR> section for more information about these.
 
-=head1 AUTHOR
+=head1 REPOSITORY
 
-Zoffix Znet, C<< <zoffix at cpan.org> >>
-(L<http://zoffix.com>, L<http://haslayout.net>)
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-github.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+
+Fork this module on GitHub:
+L<https://github.com/zoffixznet/WWW-ProxyChecker>
+
+=for html  </div></div>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-www-proxychecker at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-ProxyChecker>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-bugs.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
 
-=head1 SUPPORT
+To report bugs or request features, please use
+L<https://github.com/zoffixznet/WWW-ProxyChecker/issues>
 
-You can find documentation for this module with the perldoc command.
+If you can't access GitHub, you can email your request
+to C<bug-WWW-ProxyChecker at rt.cpan.org>
 
-    perldoc WWW::ProxyChecker
+=for html  </div></div>
 
-You can also look for information at:
+=head1 AUTHOR
 
-=over 4
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-author.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
 
-=item * RT: CPAN's request tracker
+=for html   <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/ZOFFIX"> <img src="http://www.gravatar.com/avatar/328e658ab6b08dfb5c106266a4a5d065?d=http%3A%2F%2Fwww.gravatar.com%2Favatar%2F627d83ef9879f31bdabf448e666a32d5" alt="ZOFFIX" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">ZOFFIX</span> </a> </span>
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-ProxyChecker>
+=for text Zoffix Znet <zoffix at cpan.org>
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=for html  </div></div>
 
-L<http://annocpan.org/dist/WWW-ProxyChecker>
+=head1 LICENSE
 
-=item * CPAN Ratings
+You can use and distribute this module under the same terms as Perl itself.
+See the C<LICENSE> file included in this distribution for complete
+details.
 
-L<http://cpanratings.perl.org/d/WWW-ProxyChecker>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/WWW-ProxyChecker>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Zoffix Znet, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-=cut
+=cut
\ No newline at end of file
